@@ -15,7 +15,7 @@
 
 #include <errno.h>
 
-const char* FILE_NAME = "Sys/Poll.c";
+static const char* FILE_NAME = "Sys/Poll.c";
 
 // static functions are copied from Sys/Socket.c
 static int32_t socket_errno (void) {
@@ -80,7 +80,7 @@ int32_t SPVM__Sys__Poll__poll(SPVM_ENV* env, SPVM_VALUE* stack) {
 #endif
 
   if (ready_count == -1) {
-    env->die(env, stack, "[System Error]poll failed: %s", socket_strerror(env, stack, socket_errno(), 0), __func__, FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]poll() failed:%s", socket_strerror(env, stack, socket_errno(), 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
